/*
 * Kuzzle, a backend software, self-hostable and ready to use
 * to power modern apps
 *
 * Copyright 2015-2021 Kuzzle
 * mailto: support AT kuzzle.io
 * website: http://kuzzle.io
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * @typedef Condition
 * @type {object}
 * @property {string} id
 * @property {Array<Subfilter>} subfilters
 * @property {string} keyword
 * @property {object} value
 *
 * Stores a filter condition.
 *
 * This allows V8 to convert this object to a pure
 * C++ class, with direct access to its members,
 * instead of a dictionary with b-search access time
 *
 * @class Condition
 * @param {string} id - condition unique id
 * @param {Subfilter} subfilter - subfilter referring to this condition
 * @param {string} keyword - corresponding Koncorde keyword
 * @param {object} value - condition value
 */
class Condition {
  constructor (id, subfilter, keyword, value) {
    this.id = id;
    this.subfilters = new Set([subfilter]);
    this.keyword = keyword;
    this.value = value;
  }
}

/**
 * @type {Condition}
 */
module.exports = Condition;
