"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.flattenObject = void 0;
/**
 * Flatten an object transform:
 * {
 *  title: "kuzzle",
 *  info : {
 *    tag: "news"
 *  }
 * }
 *
 * Into an object like:
 * {
 *  title: "kuzzle",
 *  info.tag: news
 * }
 *
 * @param {Object} target the object we have to flatten
 * @returns {Object} the flattened object
 */
function flattenObject(target) {
    const output = {};
    flattenStep(output, target);
    return output;
}
exports.flattenObject = flattenObject;
function flattenStep(output, object, prev = null) {
    const keys = Object.keys(object);
    for (let i = 0; i < keys.length; i++) {
        const key = keys[i];
        const value = object[key];
        const newKey = prev ? prev + '.' + key : key;
        if (Object.prototype.toString.call(value) === '[object Object]') {
            output[newKey] = value;
            flattenStep(output, value, newKey);
        }
        output[newKey] = value;
    }
}
//# sourceMappingURL=Flatten.js.map